@@ -100,7 +100,7 @@ TEMPLATE_EXTENSION = '.em'
 
 def __place_template_folder(group, src, dst, gbp=False):
     template_files = pkg_resources.resource_listdir(group, src)
-    # For each tempalte, place
+    # For each template, place
     for template_file in template_files:
         if not gbp and os.path.basename(template_file) == 'gbp.conf.em':
             debug("Skipping template '{0}'".format(template_file))
@@ -112,7 +112,7 @@ def __place_template_folder(group, src, dst, gbp=False):
             __place_template_folder(group, template_path, template_dst, gbp)
         else:
             try:
-                debug("Placing temaplte '{0}'".format(template_path))
+                debug("Placing template '{0}'".format(template_path))
                 template = pkg_resources.resource_string(group, template_path)
             except IOError as err:
                 error("Failed to load template "
@@ -278,15 +278,22 @@ def generate_substitutions_from_package(
     data['Maintainers'] = ', '.join(maintainers)
     # Changelog
     changelogs = get_changelogs(package, releaser_history)
+    if changelogs and package.version not in [x[0] for x in changelogs]:
+        warning("")
+        warning("A CHANGELOG.rst was found, but no changelog for this version was found.")
+        warning("You REALLY should have a entry (even a blank one) for each version of your package.")
+        warning("")
     if not changelogs:
         # Ensure at least a minimal changelog
-        changelogs = [(
+        changelogs = []
+    if package.version not in [x[0] for x in changelogs]:
+        changelogs.insert(0, (
             package.version,
             get_rfc_2822_date(datetime.datetime.now()),
-            '  * Autogenerated, no CHANGELOG.rst found during generation.',
+            '  * Autogenerated, no changelog for this version found in CHANGELOG.rst.',
             package.maintainers[0].name,
             package.maintainers[0].email
-        )]
+        ))
     data['changelogs'] = changelogs
     # Summarize dependencies
     summarize_dependency_mapping(data, depends, build_depends, resolved_deps)
